@@ -95,8 +95,8 @@ def init(
 
             spec = importlib.util.find_spec("specfact_cli")
             if spec and spec.origin:
-                package_dir = Path(spec.origin) #.parent.parent
-                templates_dir = package_dir / "resources" / "prompts"
+                package_dir = Path(spec.origin).parent.parent
+                templates_dir = package_dir / "site-packages" / "specfact_cli" / "resources" / "prompts"
                 if not templates_dir.exists():
                     # Fallback: try resources/prompts in project root
                     templates_dir = Path(__file__).parent.parent.parent.parent / "resources" / "prompts"
